@@ -1,6 +1,7 @@
 Plot.CA <- function(CA, titles = NA, xlabel = NA, ylabel = NA,
                     size = 1.1, grid = TRUE, color = TRUE, 
-                    linlab = NA, casc = TRUE) {
+                    linlab = NA, savptc = FALSE, width = 3236, 
+                    height = 2000, res = 300, casc = TRUE) {
   # Rotina para Plotar Graficos do Metodo AC desenvolvida 
   # por Paulo Cesar Ossani em 11/2014
   
@@ -13,6 +14,10 @@ Plot.CA <- function(CA, titles = NA, xlabel = NA, ylabel = NA,
   # grid   - Coloca grade nos graficos.
   # color  - Graficos coloridos (default = TRUE).
   # linlab - Vetor com os rotulos para as observacoes.
+  # savptc - Salva as imagens dos graficos em arquivos (default = FALSE).
+  # width  - Largura do grafico quanto savptc = TRUE (defaul = 3236).
+  # height - Altura do grafico quanto savptc = TRUE (default = 2000).
+  # res    - Resolucao nominal em ppi do grafico quanto savptc = TRUE (default = 300).
   # casc   - Efeito cascata na apresentacao dos graficos (default = TRUE).
   
   # Retorna:
@@ -43,6 +48,18 @@ Plot.CA <- function(CA, titles = NA, xlabel = NA, ylabel = NA,
   if (!is.na(linlab[1]) && length(linlab)!=nrow(CA$mtxX) && CA$typdata=="F")
      stop("O numero elementos do rotulo para linhas 'linlab' difere do numero de linhas da base de dados. Verifique!")
   
+  if (!is.logical(savptc))
+     stop("Entrada para 'savptc' esta incorreta, deve ser TRUE ou FALSE. Verifique!")
+  
+  if (!is.numeric(width) || width <= 0)
+     stop("Entrada para 'width' esta incorreta, deve ser numerica e maior que zero. Verifique!")
+
+  if (!is.numeric(height) || height <= 0)
+     stop("Entrada para 'height' esta incorreta, deve ser numerica e maior que zero. Verifique!")
+  
+  if (!is.numeric(res) || res <= 0)
+     stop("Entrada para 'res' esta incorreta, deve ser numerica e maior que zero. Verifique!")
+
   if (!is.logical(casc))
      stop("Entrada para 'casc' esta incorreta, deve ser TRUE ou FALSE. Verifique!")
 
@@ -54,16 +71,27 @@ Plot.CA <- function(CA, titles = NA, xlabel = NA, ylabel = NA,
   
   #####   FIM - Informacoes usadas nos Graficos  #####
   
-  if (casc) dev.new() # efeito cascata na apresentacao dos graficos
+  if (savptc) {
+     cat("\014") # limpa a tela
+     cat("\n\n Salvando graficos em disco. Aguarde o termino!")
+  }
+  
+  if (casc && !savptc) dev.new() # efeito cascata na apresentacao dos graficos
   
   ##### INICIO - Plotagem dos Autovalores #####
+  if (savptc) png(filename = "Figure CA Variances.png", width = width, height = height, res = res) # salva os graficos em arquivos
+  
   mp <- barplot(CA$mtxAutvlr[,1],names.arg=paste(round(CA$mtxAutvlr[,2],2),"%",sep=""),
                 main = "Variancias dos componentes")
-  ##### FIM - Plotagem dos Autovalores #####
   
-  if (casc) dev.new() # efeito cascata na apresentacao dos graficos
+  if (savptc) { box(col = 'white'); dev.off() }
+  ##### FIM - Plotagem dos Autovalores #####
+
+  if (casc && !savptc) dev.new() # efeito cascata na apresentacao dos graficos
 
   ##### INICIO - Scree-plot dos componentes #####
+  if (savptc) png(filename = "Figure CA Scree Plot.png", width = width, height = height, res = res) # salva os graficos em arquivos
+  
   plot(1:length(CA$mtxAutvlr[,1]), CA$mtxAutvlr[,1], 
        type = "n", # nao plota pontos
        xlab = "Ordem dos componentes", 
@@ -86,53 +114,61 @@ Plot.CA <- function(CA, titles = NA, xlabel = NA, ylabel = NA,
   }
   
   points(1:length(CA$mtxAutvlr[,1]), CA$mtxAutvlr[,1], type = "b")
+  
+  if (savptc) { box(col = 'white'); dev.off() }
   ##### FIM - Scree-plot dos componentes #####  
   
   ##### INICIO - Plotagem dos Dados das linhas #####
-  if (CA$typdata=="F") { # plota se nao for analise de correspondencia multipla
+  if (CA$typdata == "F") { # plota se nao for analise de correspondencia multipla
     
-    if (casc) dev.new() # efeito cascata na apresentacao dos graficos
+     if (savptc) png(filename = "Figure CA Observations.png", width = width, height = height, res = res) # salva os graficos em arquivos
     
-    plot(CA$mtxX, # cria grafico para as coordenadas principais das linhas
-         xlab = xlabel, # Nomeia Eixo X
-         ylab = ylabel, # Nomeia Eixo Y
-         main = titles[2], # Titulo
-         # asp  = 1,  # Aspecto do Grafico
-         type = "n", # nao plota pontos 
-         xlim = c(min(CA$mtxX[,1])-0.1,max(CA$mtxX[,1])+0.1), # Dimensao para as linhas do grafico
-         ylim = c(min(CA$mtxX[,2]-0.1),max(CA$mtxX[,2])+0.1)) # Dimensao para as colunas do grafico
+     if (casc && !savptc) dev.new() # efeito cascata na apresentacao dos graficos
+    
+     plot(0, # cria grafico para as coordenadas principais das linhas
+          xlab = xlabel, # Nomeia Eixo X
+          ylab = ylabel, # Nomeia Eixo Y
+          main = titles[2], # Titulo
+          type = "n", # nao plota pontos 
+          xlim = c(min(CA$mtxX[,1])-0.1,max(CA$mtxX[,1])+0.1), # Dimensao para as linhas do grafico
+          ylim = c(min(CA$mtxX[,2]-0.1),max(CA$mtxX[,2])+0.1)) # Dimensao para as colunas do grafico 
 
-    if (grid) {
+     if (grid) {
       
-       args <- append(as.list(par('usr')), c('gray93','gray93'))
+        args <- append(as.list(par('usr')), c('gray93','gray93'))
       
-       names(args) <- c('xleft', 'xright', 'ybottom', 'ytop', 'col', 'border')
+        names(args) <- c('xleft', 'xright', 'ybottom', 'ytop', 'col', 'border')
       
-       do.call(rect, args) # chama a funcao rect com os argumentos (args)
+        do.call(rect, args) # chama a funcao rect com os argumentos (args)
       
-       grid(col = "white", lwd = 2, lty = 7, equilogs = T)
+        grid(col = "white", lwd = 2, lty = 7, equilogs = T)
       
-    }
+     }
     
-    points(CA$mtxX, # cria grafico para as coordenadas principais das linhas
-           pch = 17, # Formato dos pontos 
-           cex = size,  # Tamanho dos pontos  
-           col = ifelse(color,"red","black")) # Cor dos pontos
-      
-    abline(h = 0, v=0, cex = 1.5, lty=2) # cria o eixo central
+     points(CA$mtxX, # cria grafico para as coordenadas principais das linhas
+            pch = 17, # Formato dos pontos 
+            cex = size,  # Tamanho dos pontos  
+            col = ifelse(color,"red","black")) # Cor dos pontos
+       
+     abline(h = 0, v=0, cex = 1.5, lty=2) # cria o eixo central
     
-    if (!is.na(linlab[1])) LocLab(CA$mtxX,cex=1, linlab)
+     if (!is.na(linlab[1])) LocLab(CA$mtxX,cex=1, linlab)
+    
+     if (savptc) { box(col = 'white'); dev.off() }
   }
+  
   ##### FIM - Plotagem dos Dados das linhas #####
   
-  if (casc) dev.new() # efeito cascata na apresentacao dos graficos
+  if (casc && !savptc) dev.new() # efeito cascata na apresentacao dos graficos
   
   ##### INICIO - Plotagem Dados das colunas #####
-  plot(CA$mtxY, # cria grafico para as coordenadas principais das linhas
+  if (savptc) png(filename = "Figure CA Variables.png", width = width, height = height, res = res) # salva os graficos em arquivos
+  
+  plot(0, # cria grafico para as coordenadas principais das linhas
        xlab = xlabel, # Nomeia Eixo X
        ylab = ylabel, # Nomeia Eixo Y
        main = titles[3], # Titulo
-       # asp  = 1, # Aspecto do Grafico
+       type = "n", # nao plota pontos 
        xlim = c(min(CA$mtxY[,1])-0.1,max(CA$mtxY[,1])+0.1), # Dimensao para as linhas do grafico
        ylim = c(min(CA$mtxY[,2]-0.1),max(CA$mtxY[,2])+0.1)) # Dimensao para as colunas do grafico
 
@@ -156,20 +192,23 @@ Plot.CA <- function(CA, titles = NA, xlabel = NA, ylabel = NA,
   abline(h = 0, v=0, cex = 1.5, lty=2) # cria o eixo central
   
   LocLab(CA$mtxY, cex=1, rownames(CA$mtxY))
+  
+  if (savptc) { box(col = 'white'); dev.off() }
   ##### FIM - Plotagem Dados das colunas #####
   
   ##### INICIO - Plotagem dos Dados das linhas e colunas conjuntamente #####
   if (CA$typdata=="F") { # plota se nao for analise de correspondencia multipla
     
-     if (casc) dev.new() # efeito cascata na apresentacao dos graficos
+     if (savptc) png(filename = "Figure CA Variables Observations.png", width = width, height = height, res = res) # salva os graficos em arquivos
     
-     plot(CA$mtxX,    # cria grafico para as coordenadas principais das linhas
+     if (casc && !savptc) dev.new() # efeito cascata na apresentacao dos graficos
+    
+       plot(0,    # cria grafico para as coordenadas principais das linhas
           xlab = xlabel, # Nomeia Eixo X
           ylab = ylabel, # Nomeia Eixo Y
-          main = titles[4], # Titulo
-          # asp  = 1,  # Aspecto do Grafico
-          xlim = c(min(CA$mtxX[,1],CA$mtxY)-0.1,max(CA$mtxX[,1],CA$mtxY)+0.1), # Dimensao para as linhas do grafico
-          ylim = c(min(CA$mtxX[,2],CA$mtxY)-0.1,max(CA$mtxX[,2],CA$mtxY)+0.1)) # Dimensao para as colunas do grafico
+          type = "n", # nao plota pontos 
+          xlim = c(min(CA$mtxX[,1],CA$mtxY[,1])-0.1,max(CA$mtxX[,1],CA$mtxY[,1])+0.1), # Dimensao para as linhas do grafico
+          ylim = c(min(CA$mtxX[,2],CA$mtxY[,2])-0.1,max(CA$mtxX[,2],CA$mtxY[,2])+0.1)) # Dimensao para as colunas do grafico
 
      if (grid) {
        
@@ -193,6 +232,11 @@ Plot.CA <- function(CA, titles = NA, xlabel = NA, ylabel = NA,
      abline(h = 0, v=0, cex = 1.5, lty=2) # cria o eixo central
      
      if (!is.na(linlab[1])) LocLab(rbind(CA$mtxX[,1:2], CA$mtxY[,1:2]), cex=1, rbind(as.matrix(linlab), as.matrix(rownames(CA$mtxY))))
+  
+     if (savptc) { box(col = 'white'); dev.off() }
   }
+  
   ##### FIM - Plotagem dos Dados das linhas e colunas conjuntamente #####
-}
+  
+  if (savptc) cat("\n \n Fim!")
+}
\ No newline at end of file
